// Persistence of Vision Ray Tracer Scene Description File
// File: jldesert.pov
// Vers: 3.5
// Desc: A lighthouse keeper in the desert sun
// Date: 08/29/02
// Auth: Jochen Lippert
//
#version 3.5;

#include "colors.inc"
#include "textures.inc"

// Local includes
#include "globals.inc"
#include "landscap.inc"
#include "lhtop.inc"
#include "dude.inc"

global_settings
{
	assumed_gamma 1.0
}

#declare UseLandscape=on;
#declare UseLighthouse=on;
#declare UseDude=on;
#declare UseRivets=on;

// Final camera
//#declare CamPos = <0, 0.90, -2.0>;
#declare CamPos = <0.0, 0.85, -2.0>;
#declare MyCam = camera
{
	location  CamPos
	direction z
	right     x * image_width / image_height
	look_at   <-0.30, 0.86,  0.0>
	angle 20
}

// Main light source
#declare MyLight1 = light_source
{
	// Position
	SunPos * 2,
	color rgb 1
	parallel
	point_at <0, 0, 0>
}

// Additional light
#declare MyLight2 = light_source
{
	<0, 0, 0>
	color rgb 0.2
	translate <-15, 50, 250>
	parallel
	point_at <-15, 0, 250>
	shadowless
}

// ----------------------------------------

camera {MyCam}
light_source {MyLight1}
light_source {MyLight2}

// Test light
/*
light_source {
	SunPos * <-1, 1, -1>
	color rgb 0.1
	parallel
	// Point at cam
	point_at <0, 0, 0>
	shadowless
}
*/

// Test cam
/*
camera {
  location  <0, 3, 6>
  direction 1.5*z
  right     x*image_width/image_height
  look_at   <0, 0.8,  0.0> // lamp test
  angle 7
}
*/

sky_sphere
{
	pigment
	{
		gradient y
		color_map
		{
			//[0.0 rgb <0.8,0.8,0.6>]
			//[0.7 rgb <0.8,0.3,0.3>]
			[0.0 rgb <0.8,0.7,0.5>]
			[0.1 rgb <0.8,0.8,0.6>]
		}
	}
}

// ----------------------------------------

// Main lighthouse stuff

// Build Platform object
#declare PlatThing1 = cylinder
{
	0,
	y * 0.05, 0.001
}

#declare PlatThing2 = cylinder
{
	<0.04, 0.002, 0>,
	y * -0.04, 0.003
}

#declare Platform = union
{
  	cylinder
  	{
  		0,
  		0.005 * y, 0.15
  	}
  	PlaceObjectsAtCircle(PlatThing1, 0.148, 80)
	torus
	{
		0.148,
		0.002
		translate y * 0.05
	}
	torus
	{
		0.148,
		0.002
		translate y * 0.015
	}
  	PlaceObjectsAtCircle(PlatThing2, 0.1, 12)
   	texture {MyBlack}
	rotate y * 1
}

// Build Rivets
#declare Rivet = sphere
{
	0, 0.002
}

// "Black" rivets
#declare Rivets1 = union
{
	PlaceObjectsAtCircle(Rivet, 0.1 - 0.001, 100)
}

// "Red" rivets
#declare Rivets2 = union
{
	PlaceObjectsAtCircle(Rivet, 0.109 - 0.001, 100)
}

// Lighthouse
#declare Lighthouse = union
  {
  	// Red cone
  	cone
  	{
    	1.8 * y, 0.1,
    	0, 0.2
    	texture {MyRed}
  	}
  	// Middle, white cone
  	cone
  	{
  		1.2 * y, 0.135,
  		0.6 * y, 0.168
		texture {MyWhite}
  	}
  	// Upper platform
  	object
  	{
  		Platform
		translate y * 1.8
  	}
  	// Lower platform
  	object
  	{
  		Platform
  		translate y * 1.65
  	}
  	// Top (lamp, roof etc.)
  	object
  	{
  		LighthouseTop
  		translate y * 1.8
  	}
}

#if (UseLandscape)
object
{
	Landscape
}
#end

#if (UseLighthouse)
object
{
	Lighthouse
	translate y * -1
}
#end

#if (UseDude)
object
{
	Dude
	scale 0.092
	translate z * -0.14
	rotate y * 107
	translate y * 0.8
	//translate <-0.13, 0.8, 0>
}
#end

#if (UseRivets)
  	// Black rivets, from bottom to top
  	object
  	{
  		Rivets1
  		texture {MyBlack}
  		translate y * 0.81
  	}
  	object
  	{
  		Rivets1
  		texture {MyBlack}
  		translate y * 0.888
  	}
  	object
  	{
  		Rivets1
  		texture {MyBlack}
  		translate y * 0.895
  	}
  	object
  	{
  		Rivets1
  		texture {MyBlack}
  		translate y * 0.985
  	}
  	object
  	{
  		Rivets1
  		texture {MyBlack}
  		translate y * 0.992
  	}
  	// Red rivets
  	object
  	{
  		Rivets2
  		texture {MyRed}
  		translate y * 0.66
  	}
#end
